Django Nomad Notifier — django-nomad-notifier 0.1 documentation

### Navigation

- index
- next |
- django-nomad-notifier 0.1 documentation »

# Django Nomad Notifier

## Overview

This Django app provides a way to implement a system of notifications for the users of web apps that tipically must receive updates from the site activity through channels such as emails (they call them “transactional emails” nowadays) and displayed/listed on UI (“ala” social apps such as Facebook or Google+).

Contents:

- Installation
  - Initial setup

### Navigation

- index
- next |
- django-nomad-notifier 0.1 documentation »